@@ -28,12 +28,13 @@ from .exc import (
     UnknownTypeException,
     UnknownConfigurationOption
 )
-from .fields import ModelFieldList, ModelFormField
+from .fields import ModelFieldList, ModelFormField, CountryField
 from .generator import FormGenerator
 
 
 __all__ = (
     AttributeTypeException,
+    CountryField,
     DateRange,
     InvalidAttributeException,
     ModelFieldList,
@@ -50,7 +51,7 @@ __all__ = (
 )
 
 
-__version__ = '0.12.4'
+__version__ = '0.12.5'
 
 
 def model_form_meta_factory(base=FormMeta):
@@ -74,6 +75,8 @@ def model_form_meta_factory(base=FormMeta):
     .. code-block:: python
 
         from wtforms.form import FormMeta
+
+
         class MyModelFormMeta(FormMeta):
             # do some metaclass magic here
             pass
